==> ingdao-0.0.19.tar.gz: lib/dataflow/field/dfnumericvalidator.dart <==
import 'dfvalidator.dart';
import '../control/dfresponse.dart';

class MinValueValidateException extends DfError {
   MinValueValidateException(double minValue) : super(code: 10011, message: "Input value is less than $minValue");
}

class MaxValueValidateException extends DfError {
   MaxValueValidateException(double maxValue) : super(code: 10012, message: "Input value is greater than $maxValue");
}

class DfNumericValidator extends DfValidator {

  double minValue;
  double maxValue;

  DfNumericValidator({bool isAllowEmpty = true, this.minValue, this.maxValue}) : super(isAllowEmpty: isAllowEmpty);

  MinValueValidateException minValueValidate() {
    if (emptyValidate() == null && minValue != null) {
      double dblVal = field.value as double;
      return dblVal < minValue ? MinValueValidateException(minValue) : null;
    }
    return null;
  }

  MaxValueValidateException maxValueValidate() {
    if (emptyValidate() == null && maxValue != null) {
      double dblVal = field.value as double;
      return dblVal > maxValue ? MaxValueValidateException(maxValue) : null;
    }
    return null;
  }

  List<DfError> validate() {
    List<DfError> errors = List<DfError>();
    DfError emptyErr = emptyValidate();
    if (emptyErr != null) {
      errors.add(emptyErr);
    }

    DfError minValueErr = minValueValidate();
    if (minValueErr != null) {
      errors.add(minValueErr);
    }

    DfError maxLenErr = maxValueValidate();
    if (maxLenErr != null) {
      errors.add(maxLenErr);
    }

    return errors.length > 0 ? errors : null;
  }
}

==> ingdao-0.0.28.tar.gz: lib/dataflow/field/dfnumericvalidator.dart <==
import 'dfvalidator.dart';
import '../control/dfresponse.dart';

class MinValueValidateException extends DfError {
   MinValueValidateException(double val, double minValue) : super(code: 10011, message: "Input value: \"$val\" is less than $minValue");
}

class MaxValueValidateException extends DfError {
   MaxValueValidateException(double val, double maxValue) : super(code: 10012, message: "Input value: \"$val\" is greater than $maxValue");
}

class DfNumericValidator extends DfValidator {

  double minValue;
  double maxValue;

  DfNumericValidator({bool isAllowEmpty = true, this.minValue, this.maxValue}) : super(isAllowEmpty: isAllowEmpty);

  MinValueValidateException minValueValidate() {
    if (emptyValidate() == null && minValue != null) {
      double dblVal = field.value as double;
      return dblVal < minValue ? MinValueValidateException(dblVal,minValue) : null;
    }
    return null;
  }

  MaxValueValidateException maxValueValidate() {
    if (emptyValidate() == null && maxValue != null) {
      double dblVal = field.value as double;
      return dblVal > maxValue ? MaxValueValidateException(dblVal,maxValue) : null;
    }
    return null;
  }

  List<DfError> validate() {
    List<DfError> errors = List<DfError>();
    DfError emptyErr = emptyValidate();
    if (emptyErr != null) {
      errors.add(emptyErr);
    }

    DfError minValueErr = minValueValidate();
    if (minValueErr != null) {
      errors.add(minValueErr);
    }

    DfError maxLenErr = maxValueValidate();
    if (maxLenErr != null) {
      errors.add(maxLenErr);
    }

    return errors.length > 0 ? errors : null;
  }
}
